@@ -563,6 +563,10 @@ RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *,
 #endif
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 
+#if defined(NVCPU_X86) || defined(NVCPU_X86_64)
+NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
+#endif
+
 /*
  * ---------------------------------------------------------------------------
  *
