@@ -682,9 +682,8 @@ BOOL NV_API_CALL os_is_efi_enabled(void)
 
 RM_STATUS NV_API_CALL os_get_efi_screen_info(
     NvU64 *pPhysicalAddress,
-    NvU32 *pWidth,
     NvU32 *pHeight,
-    NvU32 *pBpp
+    NvU32 *pPitch
 )
 {
     return RM_ERR_NOT_SUPPORTED;
@@ -787,6 +786,11 @@ NvBool NV_API_CALL os_is_xen_dom0(void)
     return FALSE;
 }
 
+NvBool NV_API_CALL os_is_vgx_hyper(void)
+{
+    return FALSE;
+}
+
 void NV_API_CALL os_bug_check(NvU32 bugCode, const char *bugCodeStr)
 {
 }
